==> ogre-2.2.4-1-x86_64.pkg.tar.zst: usr/include/OGRE/MeshLodGenerator/OgreLodCollapseCostProfiler.h <==

/*
 * -----------------------------------------------------------------------------
 * This source file is part of OGRE
 * (Object-oriented Graphics Rendering Engine)
 * For the latest info, see http://www.ogre3d.org/
 *
 * Copyright (c) 2000-2014 Torus Knot Software Ltd
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 * -----------------------------------------------------------------------------
 */

#ifndef _LodCollapseCostProfiler_H__
#define _LodCollapseCostProfiler_H__

#include "OgreLodPrerequisites.h"
#include "OgreLodCollapseCost.h"
#include "OgreLodData.h"
#include "OgreLodConfig.h"

namespace Ogre
{

    class _OgreLodExport LodCollapseCostProfiler :
        public LodCollapseCost
    {
    public:
        LodCollapseCostProfiler(LodProfile& profile, LodCollapseCostPtr& costCalculator) : mProfile(profile), mCostCalculator(costCalculator) {}
        virtual void initCollapseCosts(LodData* data);
        virtual void computeVertexCollapseCost(LodData* data, LodData::Vertex* vertex, Real& collapseCost, LodData::Vertex*& collapseTo);
        virtual Real computeEdgeCollapseCost(LodData* data, LodData::Vertex* src, LodData::Edge* dstEdge);
    protected:

        struct ProfiledEdge
        {
            LodData::Vertex* dst;
            Real cost;
        };

        typedef vector<bool>::type HasVertexProfileList;

        HasVertexProfileList mHasProfile;

        typedef unordered_multimap<LodData::Vertex*, ProfiledEdge>::type ProfileLookup;
        ProfileLookup mProfileLookup;
        LodProfile mProfile;

        // If an edge doesn't have a profile, this collapsecost algorithm will be used.
        LodCollapseCostPtr mCostCalculator;

        void injectProfile(LodData* data);
    };

}
#endif

==> ogre-14.4.1-1-x86_64.pkg.tar.zst: usr/include/OGRE/MeshLodGenerator/OgreLodCollapseCostProfiler.h <==

/*
 * -----------------------------------------------------------------------------
 * This source file is part of OGRE
 * (Object-oriented Graphics Rendering Engine)
 * For the latest info, see http://www.ogre3d.org/
 *
 * Copyright (c) 2000-2014 Torus Knot Software Ltd
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 * -----------------------------------------------------------------------------
 */

#ifndef _LodCollapseCostProfiler_H__
#define _LodCollapseCostProfiler_H__

#include "OgreLodPrerequisites.h"
#include "OgreLodCollapseCost.h"
#include "OgreLodData.h"
#include "OgreLodConfig.h"
#include "OgreHeaderPrefix.h"

namespace Ogre
{

class _OgreLodExport LodCollapseCostProfiler :
    public LodCollapseCost
{
public:
    LodCollapseCostProfiler(LodProfile& profile, LodCollapseCostPtr& costCalculator) : mProfile(profile), mCostCalculator(costCalculator) {}
    void initCollapseCosts(LodData* data) override;
    void computeVertexCollapseCost(LodData* data, LodData::Vertex* vertex, Real& collapseCost, LodData::Vertex*& collapseTo) override;
    Real computeEdgeCollapseCost(LodData* data, LodData::Vertex* src, LodData::Edge* dstEdge) override;
private:

    struct ProfiledEdge {
        LodData::Vertex* dst;
        Real cost;
    };

    typedef std::vector<bool> HasVertexProfileList;

    HasVertexProfileList mHasProfile;

    typedef std::unordered_multimap<LodData::Vertex*, ProfiledEdge> ProfileLookup;
    ProfileLookup mProfileLookup;
    LodProfile mProfile;

    // If an edge doesn't have a profile, this collapsecost algorithm will be used.
    LodCollapseCostPtr mCostCalculator;

    void injectProfile(LodData* data);
};

}

#include "OgreHeaderSuffix.h"

#endif
